const mongoose = require('mongoose');
const debug = require('debug');
const log = debug('grit');
mongoose.Promise = require('bluebird');

const connectToDatabase = ({ dbUrl }) =>
  new Promise((resolve, reject) => {
    mongoose.connect(
      dbUrl,
      {
        useNewUrlParser: true
      }
    );

    mongoose.connection.on('connected', () => {
      log('connected');
      resolve(mongoose.connection);
    });

    mongoose.connection.on('error', err => {
      log(`mongoose error: ${err}`);
      reject(err);
    });

    mongoose.connection.on('disconnected', () => {
      log('mongoose disconnected');
    });

    process.on('SIGINT', () => {
      mongoose.connection.close(() => {
        log('mongoose connection disconnected through app termination');
        process.exit(0);
      });
    });
  });

module.exports = connectToDatabase;
